$(document).ready(function () {
    $('#tblProduct').DataTable({
        "scrollX": true,
        "order": [],
        "columns": [
            { "data": "id" },
            { "data": "name" },
            { "data": "groupName1" },
            { "data": "groupName2" },
            { "data": "edit", className: "edit" },
            { "data": "view", className: "view" },
            { "data": "delete", className: "delete" },
        ],
        columnDefs: [
            { width: 100, targets: 0 },
            { width: 40, targets: 4 },
            { width: 40, targets: 5 },
            { width: 40, targets: 6 },
        ],
    });

    allProducts();
});


function allProducts() {
    $.ajax({
        type: "GET",
        url: "/st/product/allProducts",
        async: false,
        processData: false,
        contentType: false,
        async: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                var result = response.data.result;
                appendTableRow(result);

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}





function appendTableRow(result) {

    var data = [];
    for (i = 0; i < result.length; i++) {


        var product_primary_id = result[i]['product_primary_id'];
        var product_id = result[i]['product_id'];
        var group1_name = result[i]['group_level_1'];
        var group2_name = result[i]['group_level_2'];
        var product_name = result[i]['product_name'];
        var string_id = "'" + product_primary_id + "'";
        

        data.push({
            "id": product_id,
            "name": product_name,
            "groupName1":group1_name,
            "groupName2":group2_name,
            "edit": '<button class="btn btn-primary" onclick="edit(' + string_id + ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
            "view": '<button class="btn btn-success" onclick="view(' + string_id + ')"><i class="fa fa-eye" aria-hidden="true"></i></i></button>',
            "delete": '<button class="btn btn-danger" onclick="_delete(' + string_id + ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
        });

    }



    var table = $('#tblProduct').DataTable();
    table.clear();
    table.rows.add(data).draw();
    table.columns('.edit').visible(false);
    table.columns('.view').visible(false);
    table.columns('.delete').visible(false);



    if (edit_permission == 1) {
        table.columns('.edit').visible(true);
    }

    if (view_permission == 1) {
        table.columns('.view').visible(true);
    }

    if (delete_permission == 1) {
        table.columns('.delete').visible(true);
    }


}

function edit(id) {
    location.href = "/st/create_product?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/st/create_product?id=" + id + "&action=view";
}

function _delete(id) {

    $.ajax({
        type: 'DELETE',
        url: '/st/product/delete/' + id,
        data: {
            _token: $('input[name=_token]').val()
        },
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage('Product has been deleted successfully...');
                allProducts();

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        }

    });
}




/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}

