<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use App\Http\Controllers\NotificationController;
use Illuminate\Support\Facades\Route;
use Modules\St\Http\Controllers\ApprovalController;
use Modules\St\Http\Controllers\CountryListController;
use Modules\St\Http\Controllers\EmployeeActivityController;
use Modules\St\Http\Controllers\ErpSettingController;
use Modules\St\Http\Controllers\GnCustomerController;
use Modules\St\Http\Controllers\SuppliersController;
use Modules\St\Http\Controllers\SupplierSettingController;
use Modules\St\Http\Controllers\StockController;
use Modules\St\Http\Controllers\ProductSettingController;

use Modules\St\Http\Controllers\ModuleController;
use Modules\St\Http\Controllers\PermissionController;
use Modules\St\Http\Controllers\ProductController;
use Modules\St\Http\Controllers\StCustomerAttachmentController;
use Modules\St\Http\Controllers\SupplierController2;
use Modules\St\Http\Controllers\UserApprovalRequestController;
use Modules\St\Http\Controllers\UserController;
use Modules\St\Http\Controllers\UserRoleController;
use Modules\St\Http\Controllers\UserRolePermissionController;




Route::prefix('st')->group(function () {
    Route::get('/', 'StController@index');

    Route::get('/dashboard', function () {
        return view('st::dashboard');
    })->middleware('is.logged');


    Route::get('/create_supplier', function () {
        return view('st::supplier');
    })->middleware(['is.logged', 'can:st_supplier_create']);


    Route::get('/supplier_settings', function () {
        return view('st::supplier_settings');
    })->middleware(['is.logged', 'can:st_supplier_setting']);

    Route::get('/supplier_list', function () {
        return view('st::supplier_list');
    })->middleware(['is.logged', 'can:st_supplier_list']);

    Route::get('/create_product', function () {
        return view('st::product');
    })->middleware(['is.logged', 'can:st_product_create']);


    Route::get('/product_settings', function () {
        return view('st::product_settings');
    })->middleware(['is.logged', 'can:st_product_setting']);

    Route::get('/product_list', function () {
        return view('st::product_list');
    })->middleware(['is.logged', 'can:st_product_list']);


    Route::get('/st_customer', function () {
        return view('st::st_customer');
    })->middleware(['is.logged', 'can:st_customer_create']);

    Route::get('/st_customerList', function () {
        return view('st::st_customerList');
    })->middleware(['is.logged', 'can:st_customer_list']);

    Route::get('/st_customer_attachment', function () {
        return view('st::st_customer_attachment');
    })->middleware(['is.logged', 'can:st_customer_attachment']);


    Route::get('/erp_setting', function () {
        return view('st::erp_setting');
    })->middleware(['is.logged']);

    //user permission (sampath)
    Route::get('/user', function () {
        return view('st::user');
    })->middleware(['is.logged', 'can:st_system_user_create']);

    Route::get('/userList', function () {
        return view('st::userList');
    })->middleware(['is.logged', 'can:st_system_user_list']);

    Route::get('/userSetting', function () {
        return view('st::setting');
    })->middleware(['is.logged', 'can:st_system_user_setting']);

    Route::get('/permission', function () {
        return view('st::permission');
    })->middleware('is.logged');

    Route::get('/approvalList', function () {
        return view('st::approval_list');
    })->middleware('is.logged');
    // end user permission (sampath)


    Route::get('/message', function () {
        return view('st::message');
    })->middleware('is.logged');


    Route::get('/employeeActivity', function () {
        return view('st::employeeActivity');
    })->middleware(['is.logged']);

    Route::get('/countryList', function () {
        return view('st::country_list');
    })->middleware(['is.logged']);



    //** Suppliers  */
    Route::get('/supplier/settings', [SupplierController2::class, 'settings']);
    Route::get('/supplier/town/{id}', [SupplierController2::class, 'town']);
    Route::get('/supplier/isDuplicate/{id}', [SupplierController2::class, 'isDuplicate']);
    Route::get('/supplierList/allSuppliers', [SupplierController2::class, 'allSuppliers']);
    Route::get('/supplier/getSupplier/{id}', [SupplierController2::class, 'getSupplier']);

    Route::post('/supplier/save', [SupplierController2::class, 'save'])->middleware('can:st_supplier_add');
    Route::put('/supplier/update/{id}', [SupplierController2::class, 'update'])->middleware('can:st_supplier_edit');
    Route::delete('/supplier/delete/{id}', [SupplierController2::class, 'delete'])->middleware('can:st_supplier_delete');
    //** End of suppliers */


    //** Supplier Settings */
    Route::get('/supplier/settings/allCountry', [SupplierSettingController::class, 'AllCountry']);
    Route::get('/supplier/allGLPostingData', [SupplierSettingController::class, 'AllGLPostData']);
    Route::get('/supplier/settings/Bank', [SupplierSettingController::class, 'AllBanks']);
    Route::get('/supplier/settings/BankBranch', [SupplierSettingController::class, 'AllBankBranches']);
    Route::get('/supplier/settings/district', [SupplierSettingController::class, 'AllDistrict']);
    Route::get('/supplier/settings/SupplierType', [SupplierSettingController::class, 'AllSupplierType']);
    Route::get('/supplier/settings/SupplierStatus', [SupplierSettingController::class, 'AllSupplierStatus']);
    Route::get('/supplier/settings/town', [SupplierSettingController::class, 'AllTown']);

    Route::post('/supplier/settings/country', [SupplierSettingController::class, 'SaveCountry'])->middleware('can:st_supplier_setting_country_add');
    Route::post('/supplier/settings/district', [SupplierSettingController::class, 'SaveDistrict'])->middleware('can:st_supplier_setting_district_add');
    Route::post('/supplier/settings/town', [SupplierSettingController::class, 'SaveTown'])->middleware('can:st_supplier_setting_town_add');
    Route::post('/supplier/settings/SupplierType', [SupplierSettingController::class, 'SaveSupplierType']);
    Route::post('/supplier/settings/SupplierStatus', [SupplierSettingController::class, 'SaveSupplierStatus'])->middleware('can:st_supplier_setting_supplier_status_add');
    Route::post('/supplier/settings/Bank', [SupplierSettingController::class, 'SaveBank'])->middleware('can:st_supplier_setting_bank_add');
    Route::post('/supplier/settings/BankBranch', [SupplierSettingController::class, 'SaveBankBranch'])->middleware('can:st_supplier_setting_bank_branch_add');

    Route::put('/supplier/settings/country/{id}', [SupplierSettingController::class, 'UpdateCountry'])->middleware('can:st_supplier_setting_country_edit');
    Route::put('/supplier/settings/district/{id}', [SupplierSettingController::class, 'UpdateDistrict'])->middleware('can:st_supplier_setting_district_edit');
    Route::put('/supplier/settings/town/{id}', [SupplierSettingController::class, 'UpdateTown'])->middleware('can:st_supplier_setting_town_edit');
    Route::put('/supplier/settings/SupplierType/{id}', [SupplierSettingController::class, 'UpdateSupplierType']);
    Route::put('/supplier/settings/SupplierStatus/{id}', [SupplierSettingController::class, 'UpdateSupplierStatus'])->middleware('can:st_supplier_setting_supplier_status_edit');
    Route::put('/supplier/settings/Bank/{id}', [SupplierSettingController::class, 'UpdateBank'])->middleware('can:st_supplier_setting_bank_edit');
    Route::put('/supplier/settings/BankBranch/{id}', [SupplierSettingController::class, 'UpdateBankBranch'])->middleware('can:st_supplier_setting_bank_branch_edit');
    Route::put('/supplier/settings/town', [SupplierSettingController::class, 'UpdateTown'])->middleware('can:st_supplier_setting_town_edit');

    Route::delete('/supplier/settings/country/{id}', [SupplierSettingController::class, 'DisableCountry'])->middleware('can:st_supplier_setting_country_status');
    Route::delete('/supplier/settings/district/{id}', [SupplierSettingController::class, 'DisableDistrict'])->middleware('can:st_supplier_setting_district_status');
    Route::delete('/supplier/settings/town/{id}', [SupplierSettingController::class, 'DisableTown'])->middleware('can:st_supplier_setting_town_status');
    Route::delete('/supplier/settings/SupplierType/{id}', [SupplierSettingController::class, 'DisableSupplierType']);
    Route::delete('/supplier/settings/SupplierStatus/{id}', [SupplierSettingController::class, 'DisableSupplierStatus'])->middleware('can:st_supplier_setting_supplier_status_status');
    Route::delete('/supplier/settings/Bank/{id}', [SupplierSettingController::class, 'DisableBank'])->middleware('can:st_supplier_setting_bank_status');
    Route::delete('/supplier/settings/BankBranch/{id}', [SupplierSettingController::class, 'DisableBankBranch'])->middleware('can:st_supplier_setting_bank_branch_status');
    Route::delete('/supplier/settings/town', [SupplierSettingController::class, 'DisableTown'])->middleware('can:st_supplier_setting_town_status');
    //** End of supplier settings */



    //** Products */
    Route::get('/product/settings', [ProductController::class, 'settings']);
    Route::get('/product/groupLevel2/{id}', [ProductController::class, 'groupLevel2']);
    Route::get('/product/groupLevel3/{id1}/{id2}', [ProductController::class, 'groupLevel3']);
    Route::get('/product/isDuplicate/{id}', [ProductController::class, 'isDuplicate']);
    Route::get('/product/allProducts', [ProductController::class, 'allProducts']);
    Route::get('/product/getProduct/{id}', [ProductController::class, 'getProduct']);
    Route::get('/product/loadUnitOfMesurement', [ProductController::class, 'loadUnitOfMesurement']);


    Route::post('/product/save', [ProductController::class, 'save'])->middleware('can:st_product_add');
    Route::put('/product/update/{id}', [ProductController::class, 'update'])->middleware('can:st_product_edit');
    Route::delete('/product/delete/{id}', [ProductController::class, 'delete'])->middleware('can:st_product_delete');
    //** End of products */



    //** Product Settings */
    Route::post('/products/Savegrp1', [ProductSettingController::class, 'Save1'])->middleware('can:st_product_setting_group1_add');
    Route::post('/products/Savegrp2', [ProductSettingController::class, 'Save2'])->middleware('can:st_product_setting_group2_add');
    Route::post('/products/Savegrp3', [ProductSettingController::class, 'Save3'])->middleware('can:st_product_setting_group3_add');
    Route::post('/products/SaveProdutType', [ProductSettingController::class, 'SaveProType']);
    Route::post('/products/SaveUOM', [ProductSettingController::class, 'SaveUnitOfMesurements'])->middleware('can:st_product_setting_unit_mesure_add');

    Route::get('/products/ReaDataId1', [ProductSettingController::class, 'GetGroupLevel1']);
    Route::get('/products/ReaDataId2', [ProductSettingController::class, 'GetGroupLevel2']);
    Route::get('/products/ReaDataId3', [ProductSettingController::class, 'GetGroupLevel3']);
    Route::get('/products/ReaDataProductType', [ProductSettingController::class, 'GetDataProductType']);
    Route::get('/products/ReadUOM', [ProductSettingController::class, 'GetUOM']);

    Route::get('/products/UpdateUom/{id}', [ProductSettingController::class, 'GetUpdateUom']);
    Route::get('/products/GetUpdateProductType/{id}', [ProductSettingController::class, 'GetUpdateproductType']);
    Route::get('/products/GetLevel3UpdateData/{id}', [ProductSettingController::class, 'GetUpdateLevel3']);
    Route::get('/products/GetLevel2UpdateData/{id}', [ProductSettingController::class, 'GetUpdateLevel2']);
    Route::get('/products/GetLevel1UpdateData/{id}', [ProductSettingController::class, 'GetUpdateLevel1']);

    Route::post('/products/EditUom/{id}', [ProductSettingController::class, 'UpdateUOM']);
    Route::post('/products/EditProductType/{id}', [ProductSettingController::class, 'UpdateProductType']);
    Route::post('/products/EditLevel1/{id}', [ProductSettingController::class, 'UpdateLevel1']);
    Route::post('/products/EditLevel2/{id}', [ProductSettingController::class, 'UpdateLevel2']);
    Route::post('/products/EditLevel3/{id}', [ProductSettingController::class, 'UpdateLevel3']);

    Route::delete('/products/DisableLevel1/{id}', [ProductSettingController::class, 'DisableLevel1'])->middleware('can:st_product_setting_group1_status');
    Route::delete('/products/DisableLevel2/{id}', [ProductSettingController::class, 'DisableLevel2'])->middleware('can:st_product_setting_group2_status');
    Route::delete('/products/DisableLevel3/{id}', [ProductSettingController::class, 'DisableLevel3'])->middleware('can:st_product_setting_group3_status');
    Route::delete('/products/DisableProductType/{id}', [ProductSettingController::class, 'DisableProductType']);
    Route::delete('/products/DisableUom/{id}', [ProductSettingController::class, 'DisableUom'])->middleware('can:st_product_setting_unit_mesure_status');

    Route::get('/products/LoadLevel1Data', [ProductSettingController::class, 'GetLevel1Data']);
    Route::get('/products/Belowdata1/{id}', [ProductSettingController::class, 'Belowdatalevel1']);
    //** End of product settings */




    //user permission (sampath)

    /** User Setting Controller */
    Route::post('/user/setting/saveUserRole', [UserRoleController::class, 'save'])->middleware('can:st_system_user_role_add');
    Route::get('/user/setting/allUserRole', [UserRoleController::class, 'allUserRole']);
    Route::get('/user/setting/getUserRole/{id}', [UserRoleController::class, 'getUserRole']);
    Route::put('/user/setting/updateUserRole/{id}', [UserRoleController::class, 'updateUserRole'])->middleware('can:st_system_user_role_edit');
    Route::delete('/user/setting/deleteUserRole/{id}', [UserRoleController::class, 'deleteUserRole'])->middleware('can:st_system_user_role_delete');
    /** End User Setting Controller */


    /** Permission Controller */
    Route::get('/user/permission/allModule', [PermissionController::class, 'allModule']);
    Route::post('/user/permission/savePermission', [PermissionController::class, 'savePermission']);
    Route::get('/user/permission/allPermission', [PermissionController::class, 'allPermission']);
    Route::delete('/user/permission/deletePermission/{id}', [PermissionController::class, 'deletePermission']);
    Route::get('/user/permission/getPermission/{id}', [PermissionController::class, 'getPermission']);
    Route::put('/user/permission/updatePermission/{id}', [PermissionController::class, 'updatePermission']);
    /** End Permission Controller */



    /** User Controller */
    Route::get('/user/allUserRole', [UserController::class, 'allUserRole']);
    Route::get('/user/allSupplier', [UserController::class, 'allSupplier']);
    Route::get('/user/allCustomer', [UserController::class, 'allCustomer']);
    Route::get('/user/allEmployee', [UserController::class, 'allEmployee']);
    Route::post('/user/saveUser', [UserController::class, 'saveUser'])->middleware('can:st_system_user_add');
    Route::get('/user/allUser', [UserController::class, 'allUser']);
    Route::get('/user/getUser/{user_id}/{role_id}', [UserController::class, 'getUser']);
    Route::put('/user/updateUser/{id}', [UserController::class, 'updateUser'])->middleware('can:st_system_user_edit');
    Route::delete('/user/delete/{id}', [UserController::class, 'deleteUser'])->middleware('can:st_system_user_delete');
    /** End User Controller */


    /** Modules Controller */
    Route::get('/user/setting/allModules/{id}', [ModuleController::class, 'allModules']);
    Route::post('/user/setting/allowModule', [ModuleController::class, 'allowModule']);
    Route::post('/user/setting/removeAllowedModule', [ModuleController::class, 'removeAllowedModule']);
    /** End Modules Controller */


    /** UserRolePermission Controller */
    Route::get('/user/setting/allPermissions/{role_id}/{module_id}', [UserRolePermissionController::class, 'allPermissions']);
    Route::get('/user/setting/allSubPermissions/{role_id}/{module_id}/{permission_id}', [UserRolePermissionController::class, 'allSubPermissions']);
    Route::post('/user/setting/allowPermission', [UserRolePermissionController::class, 'allowPermission']);
    /** End UserRolePermission Controller */

    /** Approval Controller */
    Route::get('/user/setting/allModules', [ApprovalController::class, 'allModules']);
    Route::get('/user/setting/allApprovals/{module_id}', [ApprovalController::class, 'allApproval']);
    Route::get('/user/setting/allSubApproval/{module_id}/{permission_id}', [ApprovalController::class, 'allSubApproval']);
    Route::get('/approval/allDesignation', [ApprovalController::class, 'allDesignation']);
    Route::get('/approval/allEmployee', [ApprovalController::class, 'allEmployee']);
    Route::get('/approval/allUserApprovalList', [ApprovalController::class, 'allUserApprovalList']);
    Route::get('/approval/getApproval/{slug_id}', [ApprovalController::class, 'getApproval']);
    Route::get('/approval/employee/{rollback_id}', [ApprovalController::class, 'employee']);

    Route::post('/approval/saveApproval', [ApprovalController::class, 'saveApproval']);
    Route::delete('/approval/delete/{approval_id}', [ApprovalController::class, 'deleteApproval']);
    Route::put('/approval/approvedAction/{rollback_id}/{slug_id}/{rule_id}', [ApprovalController::class, 'approvedAction']);
    Route::put('/approval/updateApproval', [ApprovalController::class, 'updateApproval']);
    /** End of Approval Controller */


    //customer
    Route::get('/Customer/checkcustomerID/{id}', [GnCustomerController::class, 'checkcustomerID']);
    Route::post('/Customer/saveCustomer', [GnCustomerController::class, 'saveCustomer'])->middleware('can:st_customer_add');
    Route::get('/Customer/EditCustomer/{id}', [GnCustomerController::class, 'EditCustomer']);
    Route::post('/Customer/updateCustomer', [GnCustomerController::class, 'updateCustomer'])->middleware('can:st_customer_edit');

        //customer contacts
    Route::post('/Customer/savecontacts', [GnCustomerController::class, 'savecontacts']);
    Route::get('/Customer/loadcontacts/{id}', [GnCustomerController::class, 'loadcontacts']);
    Route::delete('/Customer/deletecontacts/{id}', [GnCustomerController::class, 'deletecontacts']);
    Route::get('/Customer/EditContct/{id}', [GnCustomerController::class, 'EditContct']);
    Route::post('/Customer/updatecontacts', [GnCustomerController::class, 'updatecontacts']);
    Route::post('/Customer/saveCustomerDelivery', [GnCustomerController::class, 'saveCustomerDelivery']);
    Route::get('/Customer/loadCustomerDeliveryData/{id}', [GnCustomerController::class, 'loadCustomerDeliveryData']);
    Route::get('/Customer/editDeliveryData/{id}', [GnCustomerController::class, 'editDeliveryData']);
    Route::post('/Customer/updateCustomerDelivery', [GnCustomerController::class, 'updateCustomerDelivery']);
    Route::delete('/Customer/deleteDeliveryData/{id}', [GnCustomerController::class, 'deleteDeliveryData']);
    Route::get('/Customer/isAssignDeliveryData/{id}', [GnCustomerController::class, 'isAssignDeliveryData']);

    //customer list
    Route::get('/CustomerList/loadCustomers', [GnCustomerController::class, 'loadCustomers']);
    Route::delete('/CustomerList/deleteCustomer/{id}', [GnCustomerController::class, 'deleteCustomer']);
    Route::get('/CustomerList/isAssignedCustomer/{id}', [GnCustomerController::class, 'isAssignedCustomer']);

    //customer attachments
    Route::get('customers/all', [StCustomerAttachmentController::class, 'allCustomers']);
    Route::get('SelectedCustomers/name/{id}', [StCustomerAttachmentController::class, 'SelectedCustomersName']);
    Route::post('/attachment/upload', [StCustomerAttachmentController::class, 'upload'])->name('uploadcustomerAttachment')->middleware('can:st_customer_attachment_add');
    Route::get('CustomerAttachment/allFiles/{id}', [StCustomerAttachmentController::class, 'allFiles']);
    Route::get('/CustomerAttachment/delete/{id}', [StCustomerAttachmentController::class, 'delete'])->middleware('can:st_customer_attachment_delete');

    // end user permission (sampath)


    /** Employee Activity */
    Route::get('/employeeActivity/employees', [EmployeeActivityController::class, 'employees']);
    Route::get('/employeeActivity/search/{id}/{date_from}/{date_to}', [EmployeeActivityController::class, 'search']);
    Route::get('/employeeActivity/employeeRecordHistory/{id}', [EmployeeActivityController::class, 'employeeRecordHistory']);
    /** End Of Employee Activity */


    /** Country */
    Route::post('/countryListController/save', [CountryListController::class, 'save']);
    Route::put('/countryListController/update/{id}', [CountryListController::class, 'update']);
    Route::put('/countryListController/disable/{id}', [CountryListController::class, 'disable']);
    Route::get('/countryListController/getCountry/{id}', [CountryListController::class, 'getCountry']);
    Route::get('/countryListController/allCountries', [CountryListController::class, 'allCountries']);
    /** End of Country */



    /** ERP Setting */
    Route::post('/erpSettingController/savePayTerm', [ErpSettingController::class, 'savePayTerm']);
    Route::get('/erpSettingController/getAllPayTerm', [ErpSettingController::class, 'getAllPayTerm']);
    Route::get('/erpSettingController/getPayTerm/{id}', [ErpSettingController::class, 'getPayTerm']);
    Route::put('/erpSettingController/updatePayTerm/{id}', [ErpSettingController::class, 'updatePayTerm']);
    Route::put('/erpSettingController/disablePayTerm/{id}', [ErpSettingController::class, 'disablePayTerm']);


    Route::post('/erpSettingController/saveCurrency', [ErpSettingController::class, 'saveCurrency']);
    Route::get('/erpSettingController/getAllCurrency', [ErpSettingController::class, 'getAllCurrency']);
    Route::get('/erpSettingController/getCurrency/{id}', [ErpSettingController::class, 'getCurrency']);
    Route::put('/erpSettingController/updateCurrency/{id}', [ErpSettingController::class, 'updateCurrency']);
    Route::put('/erpSettingController/disableCurrency/{id}', [ErpSettingController::class, 'disableCurrency']);
    /** End of ERP Setting */



});
